@@ -6,4 +6,4 @@ class Debug:
 
     def __call__(self,level,msg):
         if self.debugLevel > level:
-            print msg
+            print(msg)
