@@ -13,7 +13,7 @@ class repertoire:
             return self.chemin0
         if choix=="textures":
             for d in [os.path.join(self.chemin0,"images"), "/usr/share/celestia/textures/medres"]:
-                if os.path.exists(d+'/moon.jpg'):
+                if os.path.exists(d+'/earth.png'):
                     return d
             print "erreur : pas de répertoire des planètes"
             print "=== Il faudrait installer Celestia ==="
